[geeklog-hg] geeklog: Fixed "Find all postings by ..." on user profile page w...

geeklog-cvs at lists.geeklog.net geeklog-cvs at lists.geeklog.net
Thu Mar 7 11:12:26 EST 2013


changeset 8981:8f0fd85d0f79
url:  http://project.geeklog.net/cgi-bin/hgwebdir.cgi/geeklog/rev/8f0fd85d0f79
user: Tom <websitemaster at cogeco.net>
date: Thu Mar 07 11:10:13 2013 -0500
description:
Fixed "Find all postings by ..." on user profile page when search doesn't allow empty query string (bug #0001565)

diffstat:

 system/classes/search.class.php |  4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diffs (15 lines):

diff -r e6cf7d3ca015 -r 8f0fd85d0f79 system/classes/search.class.php
--- a/system/classes/search.class.php	Mon Mar 04 11:28:49 2013 -0500
+++ b/system/classes/search.class.php	Thu Mar 07 11:10:13 2013 -0500
@@ -430,9 +430,9 @@
             return SEC_loginRequiredForm();
         }
 
         // Make sure there is a query string
         // Full text searches have a minimum word length of 3 by default
-        if ((trim($this->_query) === '') ||
+        if ((trim($this->_query) === '' && $this->_author === '') ||
                 (empty($this->_query) && empty($this->_author) && empty($this->_topic)) ||
                 ($_CONF['search_use_fulltext'] && strlen($this->_query) < 3))
         {
@@ -430,9 +430,9 @@
         }
 
-        // Make sure there is a query string
+        // Make sure there is a query string or author not all (to allow finding all posts of author)
         // Full text searches have a minimum word length of 3 by default



More information about the geeklog-cvs mailing list